@@ -1,17 +1,18 @@
 #define _GNU_SOURCE
 
-#include "create_symboliclink.h" // inline
+#include "append_list.h"	// inline
+#include "create_symboliclink.h"	// inline
+#include "do_compare_verify_one.h"	// inline
+#include "print_error.h"	// inline
+#include "read_write.h"
 #include "struct_CPDD.h"
 #include "struct_CPInfo.h"
 #include "struct_DPath.h"
 #include "struct_OPArg.h"
 #include "struct_RData.h"
 #include "struct_SDir.h"
-#include "append_list.h" // inline
-#include "print_error.h" // inline
-#include "read_write.h"
-#include "xmalloc.h" // inline
-#include "xmalloc0.h" // inline
+#include "xmalloc.h"	// inline
+#include "xmalloc0.h"	// inline
 
 #include <limits.h>
 #include <stdbool.h>
@@ -199,7 +200,7 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 	 * CPDD *cpdd = xmalloc0(sizeof(CPDD));
 	 * ↑のコードだと構造体のメンバが0で初期化されるとは限らないらしい。
 	 * 大抵の処理系では期待通りに動くらしいけど。
-	*/
+	 */
 	CPDD *cpdd = xmalloc(sizeof(CPDD));
 	cpdd->file_count = 0;
 	cpdd->dir_count = 0;
@@ -229,40 +230,49 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 	/* 三項演算子 */
 	((loop_dst - loop) == 1) ? (acount = SINGULAR) : (acount = PLURAL);
 
-	/* コピー元が.でコピー先が存在しないとき用の処理 */
-	if(acount == SINGULAR)
+	/* コピー元が単一かつ . で、コピー先が存在しないとき用の処理 */
 	{
-		char *c = oparg->argv[loop];
-		_Bool current_flag = true;
+		char *s = oparg->argv[loop];
 
-		for(;;)
+		if((acount == SINGULAR) && (*s == '.'))
 		{
-			if((*c == '.') || (*c == G_DIR_SEPARATOR))
-			{
-				c++;
-			}
-			else if(*c == '\0')
-			{
-				break;
-			}
-			else
-			{
-				current_flag = false;
-				break;
-			}
-		}
+			_Bool current_flag = true;
+			s++;
+			char t = G_DIR_SEPARATOR;
 
-		if(current_flag == true)
-		{
-			errno = 0;
-
-			if(mkdir(oparg->argv[loop_dst], 0755) == -1)
+			/* コピー元が . かどうかチェック。 ././. とかの場合は . に入れ替える。 */
+			for(;;)
 			{
-				if((errno != EEXIST) && (errno != 0))
+				if(*s == t)
 				{
-					print_error("mkdir", __FILE__, __LINE__, cpdd);
-					fprintf(stderr, "コピー先フォルダの作成に失敗しました\n");
-					exit(EXIT_FAILURE);
+					s++;
+					if(t == '.') { t = G_DIR_SEPARATOR; }
+					else { t = '.'; }
+				}
+				else if(*s == '\0')
+				{
+					oparg->argv[loop] = ".";
+					break;
+				}
+				else
+				{
+					current_flag = false;
+					break;
+				}
+			}
+
+			if(current_flag == true)
+			{
+				errno = 0;
+
+				if(mkdir(oparg->argv[loop_dst], 0755) == -1)
+				{
+					if((errno != EEXIST) && (errno != 0))
+					{
+						print_error("mkdir", __FILE__, __LINE__, cpdd);
+						fprintf(stderr, "コピー先フォルダの作成に失敗しました\n");
+						exit(EXIT_FAILURE);
+					}
 				}
 			}
 		}
@@ -319,7 +329,7 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 		 * メモ
 		 * cpコマンドの場合、引数が.だったらそのフォルダにあるファイルをコピーする。
 		 * 引数が..だとエラー。
-		*/
+		 */
 
 		_Bool link_flag = false;
 
@@ -488,7 +498,8 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 {\
 	if(cpinfo->src_type == REGULAR)\
 	{\
-		read_write(oparg, sdir, cpinfo, cpdd);\
+		read_write(oparg, cpinfo, cpdd);\
+		do_compare_verify_one(oparg, sdir, cpinfo, cpdd);\
 	}\
 	else \
 	{\
@@ -593,7 +604,8 @@ void check_overwrite(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 	{
 		if(cpinfo->src_type == REGULAR)
 		{
-			read_write(oparg, sdir, cpinfo, cpdd);
+			read_write(oparg, cpinfo, cpdd);
+			do_compare_verify_one(oparg, sdir, cpinfo, cpdd);
 		}
 		else
 		{
@@ -610,7 +622,7 @@ void check_overwrite(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 			/*
 			 * -i（上書き確認）モード
 			 * ここの処理はgoto使わずに関数にまとめた方が分かりやすいかもしれない
-			*/
+			 */
 INPUT:
 			/*
 			 * gotoのラベルの直後で変数の宣言をすると、
@@ -848,7 +860,7 @@ static VList * dir_traverse(VList *file_list, CPInfo *cpinfo_tmp, OPArg *oparg,
 				/*
 				 * sprintfは便利だってLeptonさんが言ってた。
 				 * printf系の関数は遅い？知るか。
-				*/
+				 */
 				sprintf(cpinfo->src, "%s%s%s", src_dir, G_DIR_SEPARATOR_S, d_name);
 				sprintf(cpinfo->dst, "%s%s%s", dst_dir, G_DIR_SEPARATOR_S, d_name);
 
@@ -951,7 +963,7 @@ static inline char * get_dst_plus_srcname(const char *src, const char *dst)
 		 * fnameは以下となる。
 		 * 
 		 * /ファイル名\0
-		*/
+		 */
 		if(src[i] == G_DIR_SEPARATOR)
 		{
 			flag = true;
@@ -992,7 +1004,7 @@ BASENAME_END:
 		 * return_name = xmalloc(src_len + dst_len + 1);
 		 * ↑こいつが原因だった。G_DIR_SEPARATOR_Sのことを忘れてた。
 		 * 多分これで大丈夫。
-		*/
+		 */
 		return_name = xmalloc(src_len + dst_len + (sizeof(G_DIR_SEPARATOR_S) + 1));
 		memcpy(return_name, dst, dst_len + 1);
 		strcat(return_name, G_DIR_SEPARATOR_S);
@@ -1126,7 +1138,7 @@ static inline void set_same_or_different(const VList *drive_list, const char *sr
 	/*
 	 * キャストしないと警告が出る
 	 * warning: initialization discards qualifiers from pointer target type
-	*/
+	 */
 	VList *tmplist = (VList *)drive_list;
 	char *srcdev = NULL;
 	char *dstdev = NULL;
