@@ -1,7 +1,7 @@
 /*
  * ファイルのコピーを行う。
  * 一部、copybench-1.0（New BSD License）を参考にした。
-*/
+ */
 #define _GNU_SOURCE
 
 #ifdef _DEBUG_FLAG
@@ -11,12 +11,11 @@
 #define USE_O_DIRECT_SIZE 1024 * 1024 * 1
 #endif
 
-#include "ch_time_and_mod.h" // inline
-#include "print_error.h" // inline
+#include "ch_time_and_mod.h"	// inline
+#include "print_error.h"	// inline
 #include "struct_CPDD.h"
 #include "struct_CPInfo.h"
 #include "struct_OPArg.h"
-#include "verify_hash.h"
 #include "xmalloc.h"
 
 #include "md5.h"
@@ -86,15 +85,15 @@ static off_t written_size[2];
 static off_t next_write_size[2];
 static off_t total_read_local;
 static off_t total_write_local;
-static off_t total_read_error; // スレッド用
-static off_t total_write_error; // スレッド用
+static off_t total_read_error;	// スレッド用
+static off_t total_write_error;	// スレッド用
 static int isrc;
 static int idst;
 static int buffer_size;
 static int buffer_size_half;
 static int buffer_size_thread;
-static int ri; // index number
-static int wi; // index number
+static int ri;	// index number
+static int wi;	// index number
 static long psize;
 static _Bool verify;
 
@@ -102,7 +101,7 @@ static _Bool verify;
 char *write_now;
 
 /* 関数プロトタイプ */
-void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd);
+void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd);
 inline static void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify);
 inline static void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify);
 inline static void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify);
@@ -114,7 +113,7 @@ static void * do_md5_append(void *tmp);
 
 /*******************************************************************************
 *******************************************************************************/
-void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd)
+void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 {
 	static _Bool filesystem_check = false;
 	static _Bool fallocate_support = false;
@@ -341,7 +340,7 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 	 * posix_fallocateはext4以外の、それをサポートしていないファイルシステムだとかなり遅くなる様子。
 	 * ext4だと4秒弱で終わるフォルダのコピーが、
 	 * ntfsだと12秒はかかる（何もしないと6秒弱、pwriteだと8秒ほど、ftruncateは何もしない場合とほぼ同じ）。
-	*/
+	 */
 	if((src_size_local > 0) && (open_dst == true) && (fallocate_support == true))
 	{
 		#ifdef _DEBUG_FLAG
@@ -518,29 +517,6 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 	{
 		cpinfo->d_para = INITIAL;
 	}
-
-	if(oparg->CHECK_MODE == BEFORE)
-	{
-		switch(oparg->CHECK)
-		{
-		case V_FIVE:
-			if((cpinfo->src_md5 != NULL) && (total_write_local > 0) && (cpinfo->d_para == WRITE))
-			{
-				verify_hash(oparg, sdir, cpinfo, cpdd);
-			}
-			break;
-
-		default:
-			fprintf(stderr, "ハッシュチェックオプションが不正です\n");
-			break;
-		}
-
-		if(oparg->V == VERBOS)
-		{
-			puts("");
-			fflush(stdout);
-		}
-	}
 }
 
 /*******************************************************************************
