@@ -1,9 +1,10 @@
 #include "analyze_argument.h"
 #include "check_target.h"
+#include "do_compare_verify_two.h"	// inline
 #include "get_drive_list.h"
 #include "get_settings_dir.h"
 #include "help.h"
-#include "print_error.h" // inline
+#include "print_error.h"	// inline
 #include "read_conf.h"
 #include "set_signal.h"
 #include "struct_CPDD.h"
@@ -19,7 +20,6 @@
 #include <unistd.h>
 
 /* 関数プロトタイプ */
-static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_list, const SDir *sdir, CPDD *cpdd) __attribute__((always_inline));
 static inline void delete_src(const OPArg *oparg, const VList *file_list, CPDD *cpdd) __attribute__((always_inline));
 
 /*******************************************************************************
@@ -132,7 +132,7 @@ int main(int argc, char **argv)
 	/*
 	 * close()する必要があるもの
 	 * sdir->current_fd
-	*/
+	 */
 
 	/* 基本的に、mallocしたのはfreeしてない。 */
 
@@ -141,68 +141,6 @@ int main(int argc, char **argv)
 	return EXIT_SUCCESS;
 }
 
-/*******************************************************************************
-*******************************************************************************/
-#define FILE_REMOVE \
-{\
-	errno = 0;\
-	if(unlink(cpinfo->src) == -1)\
-	{\
-		if(errno != ENOENT)\
-		{\
-			print_error("unlink", __FILE__, __LINE__, cpdd);\
-			fprintf(stderr, "`%s' の削除に失敗しました\n", cpinfo->src);\
-		}\
-	}\
-\
-	cpinfo->s_para = UNLINK;\
-}
-
-/*******************************************************************************
-*******************************************************************************/
-static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_list, const SDir *sdir, CPDD *cpdd)
-{
-	/*
-	* キャストしないと警告が出る
-	* warning: initialization discards qualifiers from pointer target type
-	*/
-	VList *tmp = (VList *)file_list;
-
-	for(;;)
-	{
-		CPInfo *cpinfo = (CPInfo *)tmp->data;
-
-		if(cpinfo->src_type == REGULAR)
-		{
-			switch(oparg->CHECK)
-			{
-			case V_FIVE:
-				if((cpinfo->src_md5 != NULL) && (cpinfo->dst_size > 0) && (cpinfo->d_para == WRITE))
-				{
-					verify_hash(oparg, sdir, cpinfo, cpdd);
-
-					if((oparg->M == MOVE) && (cpinfo->hash_check == true))
-					{
-						FILE_REMOVE
-					}
-				}
-				break;
-
-			default:
-				fprintf(stderr, "ハッシュチェックオプションが不正です");
-				break;
-			}
-		}
-
-		if(tmp->next == NULL)
-		{
-			break;
-		}
-
-		tmp = tmp->next;
-	}
-}
-
 /*******************************************************************************
 *******************************************************************************/
 #include <unistd.h>
@@ -212,9 +150,9 @@ static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_l
 static inline void delete_src(const OPArg *oparg, const VList *file_list, CPDD *cpdd)
 {
 	/*
-	* キャストしないと警告が出る
-	* warning: initialization discards qualifiers from pointer target type
-	*/
+	 * キャストしないと警告が出る
+	 * warning: initialization discards qualifiers from pointer target type
+	 */
 	VList *tmp = (VList *)file_list;
 	tmp = tmp->tail;
 
@@ -229,18 +167,18 @@ static inline void delete_src(const OPArg *oparg, const VList *file_list, CPDD *
 			{
 				if((cpinfo->d_para == WRITE) && (cpinfo->src_size <= cpinfo->dst_size))
 				{
-					FILE_REMOVE
+					SOURCE_UNLINK
 				}
 			}
 			else
 			{
 				if((cpinfo->hash_check == true) && (cpinfo->d_para == WRITE) && (cpinfo->s_para != UNLINK) && (cpinfo->src_size <= cpinfo->dst_size))
 				{
-					FILE_REMOVE
+					SOURCE_UNLINK
 				}
 				else if((cpinfo->d_para == WRITE) && (cpinfo->s_para != UNLINK) && (cpinfo->src_size == 0) && (cpinfo->dst_size == 0))
 				{
-					FILE_REMOVE
+					SOURCE_UNLINK
 				}
 			}
 			break;
@@ -248,7 +186,7 @@ static inline void delete_src(const OPArg *oparg, const VList *file_list, CPDD *
 		case SYMBOLICLINK:
 			if(cpinfo->d_para == WRITE)
 			{
-				FILE_REMOVE
+				SOURCE_UNLINK
 			}
 			break;
 
