@@ -7,9 +7,6 @@
 
 typedef enum option_flag
 {
-	ONE, /* コンペア（SHA-1） */
-	FIVE, /* コンペア（MD5） */
-	MEMCMP, /* コンペア（memcmp） */
 	V_FIVE, /* ベリファイ（MD5） */
 	BEFORE,
 	AFTER,
