@@ -46,7 +46,7 @@ static _Bool read_finish;
 		if(errno != ENOENT)\
 		{\
 			print_error("unlink", __FILE__, __LINE__, cpdd);\
-			fprintf(stderr, "%s の削除に失敗しました\n", cpinfo->dst);\
+			fprintf(stderr, "`%s' の削除に失敗しました\n", cpinfo->dst);\
 		}\
 	}
 
@@ -136,7 +136,7 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 		if((posix_memalign((void **)&buf[0], psize, buffer_size_local) != 0) || (posix_memalign((void **)&buf[1], psize, buffer_size_local) != 0))
 		{
 			fprintf(stderr, "ベリファイに失敗しました\n");
-			fprintf(stderr, "%s\n", cpinfo->dst);
+			fprintf(stderr, "`%s'\n", cpinfo->dst);
 			print_error("posix_memalign", __FILE__, __LINE__, cpdd);
 			write_log_hash_check(cpinfo, cpinfo->src_md5, "NULL", sdir, cpdd, false);
 		}
@@ -207,12 +207,14 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 		}
 		else if(cpinfo->src_size > total)
 		{
-			fprintf(stderr, "ファイルの読み込みに失敗しました、%sを削除します\n", cpinfo->dst);
+			fprintf(stderr, "ファイルの読み込みに失敗しました\n");
+			fprintf(stderr, "`%s' を削除します\n", cpinfo->dst);
 			UNLINK_MISS_FILE
 		}
 		else
 		{
-			fprintf(stderr, "ハッシュ値が一致しませんでした、%sを削除します\n", cpinfo->dst);
+			fprintf(stderr, "ハッシュ値が一致しませんでした\n");
+			fprintf(stderr, "`%s' を削除します\n", cpinfo->dst);
 			UNLINK_MISS_FILE
 		}
 		break;
